@@ -6,8 +6,8 @@
 ;; Maintainer: GioBo <boccigionata@gmail.com>
 ;; Created: 04 August 2025
 ;; URL: https://codeberg.org/GioBo/eplotly
-;; Package-Version: 20250910.2140
-;; Package-Revision: 2b509457bd8b
+;; Package-Version: 20251118.2156
+;; Package-Revision: dd8165b20726
 ;; Package-Requires: ((emacs "26.1") (jack "1.0") (f "0.21.0"))
 ;; Keywords: tools
 
@@ -128,6 +128,61 @@ multidimensional arrays)."
 		(t el)))	obj)))
 
 (defun eplotly-string (lisp-obj &optional layout)
+  (interactive)
+  (let*
+      ((plotly-tag "temp")
+       (plotly-file (if	 eplotly-dir
+			"./plotly.min.js"
+		      eplotly-minified-js))
+       (format-inst (eplotly-string-build lisp-obj plotly-tag)))
+
+    (jack-html
+     `(:html
+       (:head
+	(:script (@	:src ,plotly-file)))
+       (:body
+	(:div (@ :id ,plotly-tag :height "80%")
+	      (:script ,format-inst)))))))
+
+;; (defun eplotly-string (lisp-obj &optional layout)
+;;   "Generate the HTML string containing thejavascript script.
+
+;; Arguments:
+
+;; - LISP-OBJ: Lisp nested alist that contains the data to plot
+
+;; - LAYOUT: list alist containing the layout parameters for the plot."
+;;   (interactive)
+;;   (let*
+;;       ((plotly-tag "temp")
+;;        (plotly-file (if	 eplotly-dir
+;; 			"./plotly.min.js"
+;; 		      eplotly-minified-js))
+;;        ;; (lisp-obj (mapcar #'eplotly-rearrange-data-series lisp-obj))
+;;        (lisp-obj (mapcan #'eplotly-rearrange-data-series lisp-obj))
+;;        (format-inst  (if layout
+;; 			 (format "Plotly.newPlot('%s', %s,%s);"
+;; 				 plotly-tag
+;; 				 (json-encode
+;; 				  lisp-obj)
+;; 				 (json-encode layout))
+;; 		       (format "Plotly.newPlot('%s', %s);"
+;; 			       plotly-tag
+;; 			       (json-encode
+;; 				lisp-obj)))))
+;;     (jack-html
+;;      `(:html
+;;        (:head
+;; 	(:script (@	:src ,plotly-file)))
+;;        (:body
+;; 	(:div (@ :id ,plotly-tag :height "80%")
+;; 	      (:script ,format-inst)))))))
+
+
+
+
+
+(defun eplotly-string-build (lisp-obj plotly-tag &optional layout)
   "Generate the HTML string containing thejavascript script.
 
 Arguments:
@@ -137,10 +192,10 @@ Arguments:
 - LAYOUT: list alist containing the layout parameters for the plot."
   (interactive)
   (let*
-      ((plotly-tag "temp")
-       (plotly-file (if	 eplotly-dir
-			"./plotly.min.js"
-		      eplotly-minified-js))
+      (;; (plotly-tag "temp")
+       ;; (plotly-file (if	 eplotly-dir
+       ;; 			"./plotly.min.js"
+       ;; 		      eplotly-minified-js))
        ;; (lisp-obj (mapcar #'eplotly-rearrange-data-series lisp-obj))
        (lisp-obj (mapcan #'eplotly-rearrange-data-series lisp-obj))
        (format-inst  (if layout
@@ -153,13 +208,13 @@ Arguments:
 			       plotly-tag
 			       (json-encode
 				lisp-obj)))))
-    (jack-html
-     `(:html
-       (:head
-	(:script (@	:src ,plotly-file)))
-       (:body
-	(:div (@ :id ,plotly-tag :height "80%")
-	      (:script ,format-inst)))))))
+    format-inst))
+
+
+
+
+
+
 
 
 (defun eplotly (lisp-obj &optional layout)
